.. BeforData documentation master file, created by
   sphinx-quickstart on Thu Dec  5 15:56:33 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to BeforData's documentation!
=====================================

.. toctree::
   :maxdepth: 5
   :caption: Contents:

   usage
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
